==============
Support Matrix
==============

Supported Operating Systems
~~~~~~~~~~~~~~~~~~~~~~~~~~~

Kayobe supports the following host Operating Systems (OS):

.. note::

   Train is the last release of Kayobe to support CentOS 7 as a host OS. The
   Train release supports both CentOS 7 and 8, and provides a route for
   migration.

* CentOS 7
* CentOS 8

For information on deploying and migrating to CentOS 8, see :doc:`centos8`.

Supported container images
~~~~~~~~~~~~~~~~~~~~~~~~~~

For details of container image distributions supported by Kolla Ansible, see
the :kolla-ansible-doc:`support matrix <user/support-matrix.html>`.

For details of which images are supported on which distributions, see the
:kolla-doc:`Kolla support matrix <support_matrix>`.
